@@ -18,10 +18,10 @@
 #' 
 #' @description Estimate the parameter of a mixture model or predict the cluster of new samples. It manages heterogeneous data as well as missing and incomplete data.
 #' 
-#' @param data a data.frame, a matrix or a named list containing the data (see \emph{Details} \emph{Data format} sections).
+#' @param data a data.frame, a matrix or a named list containing the data (see \emph{Details} and \emph{Data format} sections).
 #' @param model a named list containing models and hyperparameters (see \emph{Details} section).
 #' @param algo a list containing the parameters of the SEM-Gibbs algorithm (see \emph{Details} or \link{createAlgo}).
-#' @param nClass the number of class of the mixture model. Can be a vector for \emph{mixtCompLearn} only.
+#' @param nClass the number of classes of the mixture model. Can be a vector for \emph{mixtCompLearn} only.
 #' @param criterion "BIC" or "ICL". Criterion used for choosing the best model.
 #' @param hierarchicalMode "auto", "yes" or "no". If "auto", it performs a hierarchical version of MixtComp (clustering in two classes then each classes is split in two ...) when a functional variable is present.
 #' @param nRun number of runs for every given number of class. If >1, SEM is run \code{nRun} times for every number of class, and the best according to observed likelihood is kept.
@@ -121,7 +121,8 @@
 #'   \item{nbFreeParameters: number of free parameters of the mixture}
 #'   \item{lnObservedLikelihood: observed loglikelihood}
 #'   \item{lnCompletedLikelihood: completed loglikelihood}
-#'   \item{IDClass: entropy used to compute the discriminative power (see code of \link{plotDiscrimVar})}
+#'   \item{IDClass: entropy used to compute the discriminative power of variable: -\eqn{\sum_{i=1}^n t_{ikj} log(t_{ikj})/(n * log(K))}}
+#'   \item{IDClassBar: entropy used to compute the discriminative power of variable: -\eqn{\sum_{i=1}^n (1-t_{ikj}) log((1-t_{ikj}))/(n * log(K))}}
 #'   \item{delta: similarities between variables (see \link{heatmapVar})}
 #'   \item{completedProbabilityLogBurnIn: evolution of the completed log-probability during the burn-in period (can be used to check the convergence and determine the ideal number of iteration)}
 #'   \item{completedProbabilityLogRun: evolution of the completed log-probability  after the burn-in period (can be used to check the convergence and determine the ideal number of iteration)} 
@@ -169,6 +170,7 @@
 #' |        \tab         \tab |_ lnCompletedLikelihood\cr
 #' |        \tab         \tab |_ lnObservedLikelihood \cr
 #' |        \tab         \tab |_ IDClass  \cr
+#' |        \tab         \tab |_ IDClassBar  \cr
 #' |        \tab         \tab |_ delta  \cr
 #' |        \tab         \tab |_ runTime \cr
 #' |        \tab         \tab |_ nbFreeParameters \cr
@@ -243,11 +245,11 @@
 #' 
 #' # run RMixtComp in unsupervised clustering mode + data as matrix
 #' resLearn1 <- mixtCompLearn(simData$dataLearn$matrix, simData$model$unsupervised[1:3], algo,
-#'                            nClass = 2:3, nRun = 2, nCore = 1)
+#'                            nClass = 1:2, nRun = 2, nCore = 1)
 #' 
 #' # run RMixtComp in supervised clustering mode + data as matrix
 #' resLearn2 <- mixtCompLearn(simData$dataLearn$data.frame, simData$model$supervised[1:3], algo, 
-#'                            nClass = 2:3, nRun = 2, nCore = 1)
+#'                            nClass = 1:2, nRun = 2, nCore = 1)
 #' 
 #' # run RMixtComp in predict mode + data as list
 #' resPredict <- mixtCompPredict(simData$dataPredict$list, simData$model$unsupervised[1:3], algo,
@@ -346,6 +348,64 @@ mixtCompPredict <- function(data, model = NULL, algo = resLearn$algo, resLearn,
   return(resPredict)
 }
 
+
+
+#' @title Predict using RMixtComp
+#' 
+#' @description Predict the cluster of new samples.
+#' 
+#' @param object output of \link{mixtCompLearn} function.
+#' @param newdata a data.frame, a matrix or a named list containing the data (see \emph{Details} and \emph{Data format} sections in \link{mixtCompLearn} documentation). If \code{NULL}, use the data in \code{object}.
+#' @param type if "partition", returns the estimated partition. If "probabilities", returns the probabilities to belong to each class (tik).
+#' @param nClass the number of classes of the mixture model to use from \code{object}. If \code{NULL}, uses the number maximizing the criterion.
+#' @param ... other parameters of \link{mixtCompPredict} function.
+#'
+#' @return if \code{type = "partition"}, it returns the estimated partition as a vector. If \code{type = "probabilities"}, 
+#' it returns the probabilities to belong to each class (tik) as a matrix.
+#' 
+#' @details This function is based on the generic method "predict". For a more complete output, use \link{mixtCompPredict} function.
+#' 
+#' @examples
+#' data(iris)
+#' 
+#' model <- list(Sepal.Length = "Gaussian", Sepal.Width = "Gaussian",
+#'               Petal.Length = "Gaussian", Petal.Width = "Gaussian")
+#' 
+#' resLearn <- mixtCompLearn(iris[-c(1, 51, 101), ], model = model, nClass = 1:3, nRun = 1)
+#'
+#' # return the partition
+#' predict(resLearn)
+#' 
+#' # return the tik for the 3 new irises for 2 and 3 classes
+#' predict(resLearn, newdata = iris[c(1, 51, 101), ], type = "probabilities", nClass = 2)
+#' predict(resLearn, newdata = iris[c(1, 51, 101), ], type = "probabilities", nClass = 3)
+#'
+#' @method predict MixtComp
+#' @seealso \link{mixtCompPredict}
+#' @author Quentin Grimonprez
+#' @export
+predict.MixtComp <- function(object, newdata = NULL, type = c("partition", "probabilities"), 
+                             nClass = NULL, ...)
+{
+  type = match.arg(type)
+  
+  if(is.null(nClass))
+    nClass = object$algo$nClass
+  
+  if(is.null(newdata))
+  {
+    resPredict <- extractMixtCompObject(object, nClass)
+  }else{
+    resPredict <- mixtCompPredict(newdata, resLearn = object, nClass = nClass, ...)
+  }
+  
+  out <- switch(type,
+                "partition" = getPartition(resPredict, empiric = FALSE),
+                "probabilities" = getTik(resPredict, log = FALSE))
+  
+  return(out)
+}
+
 # @author Quentin Grimonprez
 classicLearn <- function(data, model, algo, nClass, criterion, nRun, nCore, verbose, mode)
 {
@@ -446,14 +506,14 @@ hierarchicalLearn <- function(data, model, algo, nClass, criterion, minClassSize
   resLearn <- hierarchicalMixtCompLearn(data, model, algo, nClass, criterion, minClassSize, nRun, nCore, verbose)
   
   ## Choose the best number of classes according to crit
-  allCrit <- sapply(resLearn$res[-1], function(x) {c(getBIC(x), getICL(x))})
+  allCrit <- sapply(resLearn$res, function(x) {c(getBIC(x), getICL(x))})
   colnames(allCrit) = c(resLearn$nClass)
   rownames(allCrit) = c("BIC", "ICL")
   indBestClustering <- which.max(allCrit[indCrit, ])
   
   if(length(indBestClustering) != 0)
   {
-    res <- c(resLearn$res[-1][[indBestClustering]], list(nRun = nRun, criterion = criterion, crit = allCrit, nClass = resLearn$nClass, res = resLearn$res[-1]))
+    res <- c(resLearn$res[[indBestClustering]], list(nRun = nRun, criterion = criterion, crit = allCrit, nClass = resLearn$nClass, res = resLearn$res))
     res$algo$basicMode = FALSE
     res$algo$hierarchicalMode = TRUE
   }else{
